from distutils.core import setup


setup(
        name        ='JackZhu2009',
        version     ='1',
        py_modules  =['jack2020'],
        author      ='JackZhu2009',
        author_email='xtzhu81@hotmail.com',
        url         ='http://www.headfirstlabs.com',
        description ='A simple printer of nested lists',
      )
